@@ -12,6 +12,7 @@
 #include <QStandardItemModel>
 #include <QUrl>
 
+#include <KAcceleratorManager>
 #include <KColorScheme>
 #include <KConfig>
 #include <KConfigGroup>
@@ -54,8 +55,8 @@ public:
 
 WireGuardPeerWidget::Private::~Private() = default;
 
-WireGuardPeerWidget::WireGuardPeerWidget(const QVariantMap &peerData, QWidget *parent, Qt::WindowFlags f)
-    : QDialog(parent, f)
+WireGuardPeerWidget::WireGuardPeerWidget(const QVariantMap &peerData, QWidget *parent)
+    : QWidget(parent)
     , d(new Private)
 {
     d->ui.setupUi(this);
